Crate actix_admin

Crate actix_admin 

Actix Admin

The actix-admin crate aims at creating a web admin interface similar to other admin interfaces (such as flask-admin in python).

See the documentation at https://mgugger.github.io/actix-admin/.

Modules

builder
csrf
CSRF protection helpers.
model
prelude
routes
tera_templates
view_model

Macros

admin_prelude
Convenience macro: unwrap the double-Result returned by begin_route, returning early on either the propagated error or the pre-built response.

Structs

ActixAdmin
ActixAdminConfiguration
ActixAdminError
ActixAdminMenuElement
ActixAdminNotification

Enums

ActixAdminErrorType
ActixAdminNotificationType

Traits

ActixAdminSelectListTrait