pub struct ActixAdminViewModelFilter {
pub name: String,
pub value: Option<String>,
pub foreign_key: Option<String>,
pub values: Option<Vec<(String, String)>>,
pub filter_type: Option<ActixAdminModelFilterType>,
pub operators: Vec<ActixAdminFilterOperator>,
pub operator: Option<ActixAdminFilterOperator>,
}Fields
name: Stringvalue: Option<String>foreign_key: Option<String>values: Option<Vec<(String, String)>>filter_type: Option<ActixAdminModelFilterType>operators: Vec<ActixAdminFilterOperator>Which comparison operators the user may pick from. When empty, no
operator picker is rendered and the filter closure receives
operator = None (legacy behavior).
operator: Option<ActixAdminFilterOperator>The operator selected by the current request, if any.