Actix Admin
The actix-admin crate aims at creating a web admin interface similar to other admin interfaces (such as flask-admin in python).
See the documentation at https://mgugger.github.io/actix-admin/.
Modules
- builder
- csrf
- CSRF protection helpers.
- model
- prelude
- routes
- tera_
templates - view_
model
Macros
- admin_
prelude - Convenience macro: unwrap the double-Result returned by
begin_route, returning early on either the propagated error or the pre-built response.